pub struct BitSamplePoint { /* private fields */ }Expand description
BitSamplePoint is the fraction of the way through each bit the interface takes its sample.
Implementations
Sourceimpl BitSamplePoint
impl BitSamplePoint
Sourcepub const MINIMUM_SAMPLE_POINT: BitSamplePoint
pub const MINIMUM_SAMPLE_POINT: BitSamplePoint
The minimum sample point is 50%, per the spec.
Sourcepub const MAXIMUM_SAMPLE_POINT: BitSamplePoint
pub const MAXIMUM_SAMPLE_POINT: BitSamplePoint
There is no official maximum, except that seg2 must be at least one time quantum.
Sourcepub fn new(tenths_of_a_percent: u16) -> BitSamplePoint
pub fn new(tenths_of_a_percent: u16) -> BitSamplePoint
Constructs a target sample point after some sanity checking.