pub struct CanBitTimingParameters {
pub baud_rate_prescaler: u32,
pub seg1: SegmentLength,
pub seg2: SegmentLength,
pub jump_width: SegmentLength,
}Expand description
The results of an interface timing calculation.
Fields
baud_rate_prescaler: u32The CAN interface will scale the clock frequency back by this amount.
seg1: SegmentLengthThe number of time quanta before the sample point (not counting the Sync Seg Quantum).
seg2: SegmentLengthThe number of time quanta after the sample point.
jump_width: SegmentLengthThe number of time quanta to adjust seg1 and seg2 by at each synchronization step.